#
# spec file for package python3-scspell3k
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/


Name:           python3-scspell3k
Version:        2.0
Release:        1.5
License:        GPL-2.0
Summary:        A conservative interactive spell checker for source code
Url:            https://github.com/myint/scspell
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/s/scspell3k/scspell3k-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description
Scspell is a spell checker for source code. This is an
unofficial fork of scspell that runs on both Python 2 and
3.

Scspell does not try to be particularly smart--rather, it
does the simplest thing that can possibly work:

    1. All alphanumeric strings (strings of letters,
       numbers, and underscores) are spell-checked tokens.
    2. Each token is split into one or more subtokens.
       Underscores and digits always divide tokens, and
       capital letters will begin new subtokens. In other
       words, `some_variable` and `someVariable` will both
       generate the subtoken list {``some``, ``variable``}.
    3. All subtokens longer than three characters are
       matched against a set of dictionaries, and a match
       failure prompts the user for action. When matching
       against the included English dictionary, prefix
       matching is employed; this choice permits the use of
       truncated words like `dict` as valid subtokens.

When applied to code written in most popular programming
languages while using typical naming conventions, this
algorithm will usually catch many errors without an
annoying false positive rate.

In an effort to catch more spelling errors, scspell is able
to check each file against a set of dictionary words
selected *specifically for that file*. Up to three different
sub-dictionaries may be searched for any given file:

    1. A natural language dictionary. (scspell provides an
       American English dictionary as the default.)
    2. A programming language-specific dictionary, intended
       to contain oddly-spelled keywords and APIs associated
       with that language. (scspell provides small default
       dictionaries for a number of popular programming
       languages.)
    3. A file-specific dictionary, intended to contain
       uncommon strings which are not likely to be found
       in more than a handful of unique files.

%prep
%setup -q -n scspell3k-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

# Prepare for update-alternatives usage
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
mv %{buildroot}%{_bindir}/scspell %{buildroot}%{_bindir}/scspell-%{py3_ver}
ln -s -f %{_sysconfdir}/alternatives/scspell %{buildroot}%{_bindir}/scspell

%post
%_sbindir/update-alternatives \
   --install %{_bindir}/scspell scspell %{_bindir}/scspell-%{py3_ver} 30

%postun
if [ $1 -eq 0 ] ; then
    %_sbindir/update-alternatives --remove scspell %{_bindir}/scspell-%{py3_ver}
fi

%files
%defattr(-,root,root,-)
%doc COPYING.txt README.rst SCOWL-LICENSE.txt
%{_bindir}/scspell
%{_bindir}/scspell-%{py3_ver}
%ghost %{_sysconfdir}/alternatives/scspell
%{python3_sitelib}/*

%changelog
* Mon Oct 17 2016 toddrme2178@gmail.com
- Initial version
